@@ -24,12 +24,14 @@
 #include "global_vars.h"
 #include "bwm-ng.h"
 
+/* handle interrupt signal */
+void sigint(int sig) FUNCATTR_NORETURN;
+inline void init(void);
+
 /* clear stuff and exit */
 #ifdef __STDC__
-void deinit(int code, char *error_msg, ...) FUNCATTR_NORETURN;
-void deinit(int code, char *error_msg, ...) {
+void deinit(int code, const char *error_msg, ...) {
 #else
-void deinit(int code, ...) FUNCATTR_NORETURN;
 void deinit(int code, ...) {
 #endif
     va_list    ap;
@@ -90,16 +92,13 @@ void deinit(int code, ...) {
 }
 
 
-/* handle interrupt signal */
-void sigint(int sig) FUNCATTR_NORETURN;
-
 /* sigint handler */
 void sigint(int sig) {
 	/* we got a sigint, call deinit and exit */
 	deinit(0, NULL);
 }
 
-inline void init() {
+inline void init(void) {
 	if_count=0;
 	delay=500;
 #if EXTENDED_STATS	
@@ -193,7 +192,13 @@ int main (int argc, char *argv[]) {
         deinit(1,"invalid output selected\n");
     if (input_method<0)
         deinit(1,"invalid input selected\n");
-    
+        
+#ifdef LIBSTATGRAB
+	if (sg_init(0) != 0) {
+		deinit(1,"libstatgrab failed to initialise\n");
+	}
+#endif
+
     /* init total stats to zero */
 	memset(&if_stats_total,0,(size_t)sizeof(t_iface_stats));
 #ifdef HAVE_CURSES
@@ -211,9 +216,13 @@ int main (int argc, char *argv[]) {
 	if (output_method==CSV_OUT && output_count>-1) {
 		get_iface_stats(0);
 #ifdef HAVE_USLEEP
-		if (EINVAL==usleep(delay*1000)) 
-			/* there seems to be systems where 1million usecs is max */
-			usleep(999999);
+		if (usleep(delay*1000) != 0) {
+			if (errno == EINVAL) {
+				errno = 0;
+				/* there seems to be systems where 1million usecs is max */
+				usleep(999999);
+			}
+		}
 #else
 		Sleep(delay);
 #endif
