@@ -24,8 +24,17 @@
 #include "global_vars.h"
 #include "output.h"
 
+inline static const char *output_type2str(void);
+inline const char *input2str(void);
+inline const char *show_all_if2str(void);
+inline ullong direction2value(char mode,struct inout_long stats);
+#if EXTENDED_STATS
+inline double direction_max2value(char mode,struct inouttotal_double stats,int items);
+#endif
+inline char *dyn_byte_value2str(double value,char *str,int buf_size);
+char *values2str(char mode,t_iface_speed_stats stats,t_iface_stats full_stats,float multiplier,char *str,int buf_size);
 
-inline char *output_type2str() {
+inline static const char *output_type2str(void) {
 #if EXTENDED_STATS
     static char str[25];
 #endif
@@ -50,7 +59,7 @@ inline char *output_type2str() {
 }
 
 
-inline char *input2str() {
+inline const char *input2str(void) {
     switch (input_method) {
 #ifdef SYSCTL
         case SYSCTL_IN:
@@ -112,7 +121,7 @@ inline char *input2str() {
     return "";
 }
 
-inline char *show_all_if2str() {
+inline const char *show_all_if2str(void) {
     switch (show_all_if) {
         case 1:
 				return " (all)";
@@ -158,7 +167,7 @@ int print_header(int option) {
 			else {
 				width=(cols-3-16-4)/3;
 				mvwprintw(stdscr,1,2,"+---{ bwm-ng v" VERSION" }");
-				for (col=17+sizeof(VERSION);col<32+cols-48;col++) 
+				for (col=17+sizeof(VERSION);cols >= 0 && col<(unsigned int)(32+cols-48);col++) 
 					mvwprintw(stdscr,1,col,"-");
 				mvwprintw(stdscr,1,32+cols-48,"+- -- - -- -->");
 				mvwprintw(stdscr,2,2,"|"), mvwprintw(stdscr,2,32+cols-48,"|------.");
@@ -190,7 +199,7 @@ int print_header(int option) {
 
 
 				mvwprintw(stdscr,37,2,"+"); mvwprintw(stdscr,37,32+cols-48,"+");
-				for (col=3;col<32+cols-48;col++) 
+				for (col=3;cols >= 0 && col<(unsigned int)(32+cols-48);col++) 
 					mvwprintw(stdscr,37,col,"-");
 
 				mvwprintw(stdscr,38,2,"`+--> %c probing every: %2.3fs",(char)IDLE_CHARS[option],(float)delay/1000);
@@ -223,8 +232,8 @@ int print_header(int option) {
 		        fprintf(tmp_out_file,"<title>bwm-ng stats</title>\n</head>\n<body>\n");
 			}
 	        fprintf(tmp_out_file,"<div class=\"bwm-ng-header\">bwm-ng bwm-ng v" VERSION " (refresh %is); input: ",html_refresh);
-            fprintf(tmp_out_file,input2str());
-            fprintf(tmp_out_file,show_all_if2str());
+            fprintf(tmp_out_file,"%s", input2str());
+            fprintf(tmp_out_file,"%s", show_all_if2str());
 	        fprintf(tmp_out_file,"</div><table class=\"bwm-ng-output\">");
 			fprintf(tmp_out_file,"<tr class=\"bwm-ng-head\"><td class=\"bwm-ng-name\">Interface</td><td>Rx</td><td>Tx</td><td>Total</td></tr>");
 			break;
@@ -234,7 +243,7 @@ int print_header(int option) {
 			if (output_method==PLAIN_OUT && ansi_output) printf("\033[1;2H");
 	        printf("bwm-ng v" VERSION " (delay %2.3fs); ",(float)delay/1000);
 			if (output_method==PLAIN_OUT) printf("press 'ctrl-c' to end this%s",(ansi_output ? "\033[2;2H" : "")); else printf("input: ");
-            printf(input2str());
+            printf("%s", input2str());
             printf("%s\n",show_all_if2str());
 			if (output_method==PLAIN_OUT) {
 				if (ansi_output)
@@ -297,6 +306,24 @@ inline char *dyn_byte_value2str(double value,char *str,int buf_size) {
     return str;
 }
 
+inline char *dyn_bit_value2str(double value,char *str,int buf_size) {
+    if (dynamic) {
+        if (value<1000)
+            snprintf(str,buf_size,"%15.2f  ",value);
+        else
+            if (value<1000000)
+                snprintf(str,buf_size,"%15.2f k",value/1000);
+            else
+                if (value<1000000000)
+                    snprintf(str,buf_size,"%15.2f M",value/1000000);
+                else
+                    snprintf(str,buf_size,"%15.2f G",value/1000000000);
+    } else {
+        snprintf(str,buf_size,"%15.2f k",value/1000);
+    }
+    return str;
+}
+
 char *values2str(char mode,t_iface_speed_stats stats,t_iface_stats full_stats,float multiplier,char *str,int buf_size) {
     char byte_char=' ';
     char speed[3];
@@ -319,7 +346,7 @@ char *values2str(char mode,t_iface_speed_stats stats,t_iface_stats full_stats,fl
         output_unit==PACKETS_OUT) {
         switch (output_type) {
             case RATE_OUT:
-                value=(double)direction2value(mode,stats.packets)*multiplier;
+                value=(double)(direction2value(mode,stats.packets)*multiplier);
                 break;
 #if EXTENDED_STATS                
             case SUM_OUT:
@@ -340,7 +367,7 @@ char *values2str(char mode,t_iface_speed_stats stats,t_iface_stats full_stats,fl
             case BYTES_OUT:
                 switch (output_type) {
                     case RATE_OUT:
-                        value=(double)direction2value(mode,stats.bytes)*multiplier;
+                        value=(double)(direction2value(mode,stats.bytes)*multiplier);
                         break;
 #if EXTENDED_STATS
                     case SUM_OUT:
@@ -353,18 +380,20 @@ char *values2str(char mode,t_iface_speed_stats stats,t_iface_stats full_stats,fl
                         value=(double)direction_max2value(mode,full_stats.avg.item_sum.bytes,full_stats.avg.items);
 #endif
                 }
+                str_buf=(char *)malloc(buf_size);
                 if (output_unit==BITS_OUT) {
                     byte_char='b';
                     value*=8;
-                } else
-                     byte_char='B';
-                str_buf=(char *)malloc(buf_size);
-                snprintf(str,buf_size,"%s%c%s",dyn_byte_value2str(value,str_buf,buf_size),byte_char,speed);
+                    snprintf(str,buf_size,"%s%c%s",dyn_bit_value2str(value,str_buf,buf_size),byte_char,speed);
+                } else {
+                    byte_char='B';
+                    snprintf(str,buf_size,"%s%c%s",dyn_byte_value2str(value,str_buf,buf_size),byte_char,speed);
+                }
                 break;
             case ERRORS_OUT:
                 switch (output_type) {
                     case RATE_OUT:
-                        value=(double)direction2value(mode,stats.errors)*multiplier;
+                        value=(double)(direction2value(mode,stats.errors)*multiplier);
                         break;
 #if EXTENDED_STATS
                     case SUM_OUT:
@@ -387,7 +416,7 @@ char *values2str(char mode,t_iface_speed_stats stats,t_iface_stats full_stats,fl
 }
 
 /* do the actual output */
-void print_values(int y,int x,char *if_name,t_iface_speed_stats stats,float multiplier,t_iface_stats full_stats) {
+void print_values(unsigned int y,unsigned int x,const char *if_name,t_iface_speed_stats stats,float multiplier,t_iface_stats full_stats) {
    char buffer[50];
 #if CSV || HTML
 	FILE *tmp_out_file;
@@ -398,7 +427,7 @@ void print_values(int y,int x,char *if_name,t_iface_speed_stats stats,float mult
 	unsigned int row=0;
 	unsigned int col=0;
 	unsigned int width=0;
-	int i=0, j=0;
+	unsigned int i=0, j=0;
 	char adjust=0;
 #endif
     switch (output_method) {
@@ -490,10 +519,9 @@ void print_values(int y,int x,char *if_name,t_iface_speed_stats stats,float mult
         case PLAIN_OUT:
 			if (output_method==PLAIN_OUT && ansi_output) printf("\033[%d;2H",y);
             printf("%15s:",if_name); /* output the name */
-            printf("%s %s %s\n",
-                values2str(0,stats,full_stats,multiplier,buffer,49),
-                values2str(1,stats,full_stats,multiplier,buffer,49),
-                values2str(2,stats,full_stats,multiplier,buffer,49));
+            printf("%s ", values2str(0,stats,full_stats,multiplier,buffer,49));
+				printf("%s ",values2str(1,stats,full_stats,multiplier,buffer,49));
+				printf("%s\n",values2str(2,stats,full_stats,multiplier,buffer,49));
             break;
 #ifdef HTML			
 		case HTML_OUT:
@@ -558,7 +586,7 @@ void print_values(int y,int x,char *if_name,t_iface_speed_stats stats,float mult
                /* show packets/s and errors/s */
                fprintf(tmp_out_file,"%.2Lf%c%.2Lf%c%.2Lf",stats_csv_d.packets.out,csv_char,stats_csv_d.packets.in,csv_char,stats_csv_d.packets.total);
                fprintf(tmp_out_file,"%c%.2Lf%c%.2Lf\n",csv_char,stats_csv_d.errors.out,csv_char,stats_csv_d.errors.in);
-						
+					fflush(tmp_out_file);	
 				}
             break;
 #endif			
